-- Konny Rozsiewacz Nawozow KOS
-- Wersja: 1.0
--20.05.2009
-- Skrypt napisany przez Outlaw, ze zmianami wprowadzonymi przez hannibal5

---LOG---
-------------------------------------
--Wersja: 1.0 (20.05.2009)
-----Zaladunek i rozsiewanie nawozu
-----Mozliwosc edycji klawiszy i podpowiedzi
-------------------------------------

RozsiewaczKos = {};

function RozsiewaczKos.prerequisitesPresent(specializations)

    return SpecializationUtil.hasSpecialization(Trailer, specializations);
	
end;


function RozsiewaczKos:load(xmlFile)

	-----Dane dla obrotu talerza-----
	local count = getXMLInt(xmlFile, "vehicle.drums#count");
    self.drums = {}
	local part = self.drums;
    for i = 1, count do
		part[i] = {};
        local partname = string.format("vehicle.drums.part" .. "%d", i);
	    part[i].index = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, partname .. "#index"));
		local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, partname .. "#rot"));
		part[i].rot = {};
	    part[i].rot[1] = Utils.getNoNil(x, 0);
	    part[i].rot[2] = Utils.getNoNil(y, 0);
	    part[i].rot[3] = Utils.getNoNil(z, 0);
		for j = 1, 3 do
			if part[i].rot[j] ~= 0 then
				part[i].rot[j] = 1 / part[i].rot[j]
			end;
		end;
    end;
	-----Dane dla obrotu talerza-----
	
	-----Dane dla czasteczek-----
	self.dustParticleSystems = {};
    local dustParticleSystemCount = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.dustParticleSystems#count"), 0);
    for i = 1, dustParticleSystemCount do
        local namei = string.format("vehicle.dustParticleSystems.part%d", i);
		local nodei = Utils.indexToObject(self.rootNode, getXMLString(xmlFile, namei .. "#index"));
        Utils.loadParticleSystem(xmlFile, self.dustParticleSystems, namei, nodei, false, nil, self.baseDirectory)			
    end;
	-----Dane dla czasteczek-----
	
	-----Dane dla klawiszy-----
	self.keys = {};
    local i = 0;
    while true do
        local baseName = string.format("vehicle.keys.input(%d)", i);
        local inputName = getXMLString(xmlFile, baseName.. "#name");
        if inputName == nil then
            break;
        end;
        local inputKey = getXMLString(xmlFile, baseName.. "#key");
        if Input[inputKey] == nil then
            print("Error: invalid key '" .. inputKey .. "'  for input event '" .. inputName .. "'");
            break;
        end;
        self.keys[inputName] = Input[inputKey];
        i = i + 1;
    end;
	-----Dane dla klawiszy-----
	
	self.turnOn = false; --Czy kos jest wlaczony
	self.isEmpty = true; --Czy kos jest pusty
	
	
	self.keyType = InputBinding.getButtonKeyName;
	self.keyName = "Klawisz"; 
	
	if g_settingsJoystickEnabled then 
		self.keySet = not self.keySet;
	end; 	
	
	self.vehicleType = getXMLString(xmlFile, "vehicle#type"); --Typ pojazdu
	
end;

function RozsiewaczKos:mouseEvent(posX, posY, isDown, isUp, button)

end;

function RozsiewaczKos:keyEvent(unicode, sym, modifier, isDown)
	
	-----Wlaczenie kosa-----
	if self:getIsActiveForInput() and InputBinding.isPressed(InputBinding.Kos_ON) then
		self.turnOn = not self.turnOn; 
	end;
	-----Wlaczenie kosa-----
	
	-----Przelaczenie podpowiedzi, klawisze lub przyciski-----
	if isDown and sym==Input.KEY_8 then
		self.keySet = not self.keySet;		
	end;
	-----Przelaczenie podpowiedzi, klawisze lub przyciski-----
	
end;




function RozsiewaczKos:update(dt)

	if self.attacherVehicle then
		-----Wybor miedzy klawiszami lub przyciskami-----
		if self.keySet then
			self.keyType = InputBinding.getButtonName;
			self.keyName = "Przycisk"; 
		else
			self.keyType = InputBinding.getButtonKeyName;
			self.keyName = "Klawisz"; 
		end; 
		-----Wybor miedzy klawiszami lub przyciskami-----
		
		-----Kos jest wlaczony-----
		if self.turnOn and self.attacherVehicle.lastSpeed * 3600 > 1 then					
					
			for i=1, table.getn(self.drums) do
				rotate(self.drums[i].index, self.drums[i].rot[1] / 10 * dt, self.drums[i].rot[2] / 10 * dt, self.drums[i].rot[3] / 10 * dt); --Obrot talerza
			end;
			
			if self.fillLevel == 0 then
				self.isEmpty = true;
				Utils.setEmittingState(self.dustParticleSystems, false);
			end; 
			
			if self.fillLevel > 0 then
			
				self.isEmpty = false;
				
				if self.deltaLevel == nil then
					self.deltaLevel = 1; 
				end; 
				-----Rozsiewanie nawozu-----
				if not self.isEmpty then
				   	local difficultyMultiplier = math.max(3 * (3 - g_currentMission.missionStats.difficulty), 1);
					local deltaLevel = FruitUtil.fruitIndexToDesc[self.currentFillType].literPerQm * difficultyMultiplier * 2; 
					self:setFillLevel(self.fillLevel-deltaLevel, self.currentFillType);
				
	                local x,y,z = getWorldTranslation(self.cuttingAreas[1].start);
					local x1,y1,z1 = getWorldTranslation(self.cuttingAreas[1].width);
					local x2,y2,z2 = getWorldTranslation(self.cuttingAreas[1].height);
	                Utils.updateSprayArea(x, z, x1, z1, x2, z2);
			   
					Utils.setEmittingState(self.dustParticleSystems, true);
				end;
				-----Rozsiewanie nawozu-----
			end;
		-----Kos jest wlaczony-----
		else
			Utils.setEmittingState(self.dustParticleSystems, false);
		end;
		
	end; 

end;


function RozsiewaczKos:draw()

	--Jezeli kos jest wlaczony
	if self.turnOn then
		g_currentMission:addExtraPrintText(self.keyName.. " " ..self.keyType(InputBinding.Kos_ON).. ": " ..g_i18n:getText("Kos_OFF")); 
	else
	--Jezeli kos jest wylaczony
		g_currentMission:addExtraPrintText(self.keyName.. " " ..self.keyType(InputBinding.Kos_ON).. ": " ..g_i18n:getText("Kos_ON")); 
	end; 	

	--Jezeli kos jest pusty
	if self.fillLevel == 0 then
		g_currentMission:addExtraPrintText(g_i18n:getText("Kos_SILO"));
	end; 
	
end;


function RozsiewaczKos:onAttach()

end; 	


function RozsiewaczKos:onDetach()

	Utils.setEmittingState(self.dustParticleSystems, false);
	
end;


function RozsiewaczKos:delete()

	Utils.setEmittingState(self.dustParticleSystems, false);
	Utils.deleteParticleSystem(self.dustParticleSystems);
	
end;


